..
    Copyright (C) 2020-2024 CERN.

    Babel-EDTF is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.2.0 (released 2024-10-28)

- setup: upgrade edtf to 5.0.0 and fix bug with dates and times with hour 23

Version 1.1.4 (released 2024-03-05)

- fix: fail parsing 29th of February on non-leap years

Version 1.1.3 (released 2023-11-01)

- global: use custom parse_edtf in parse_edtf_level0

Version 1.1.2 (released 2023-10-19)

- add leading zeros for precise month and day

Version 1.1.1 (released 2023-10-19)

- convert isoparse values to string

Version 1.1.0 (released 2023-10-19)

- Add parse_edtf isoparse backed method

Version 1.0.0 (released 2020-11-06)

- Initial public release.
